# Changelog

## [unreleased]

## [1.0.0-post1]

- Moved documentation to Read the Docs and updated all links.

## [1.0.0]

- Initial release.

## [1.0.0-beta0]

- Pre-release.

- Added `max_version` parameter.

- Added `auth` parameter to pass GitHug auth token.

- Small bug fixes.

- Updated CI and dependencies.

[unreleased]: https://github.com/taminomara/python-vhs/compare/v1.0.0-post1...HEAD
[unreleased]: https://github.com/taminomara/python-vhs/compare/v1.0.0...v1.0.0-post1
[1.0.0]: https://github.com/taminomara/python-vhs/compare/v1.0.0-beta0...v1.0.0
[1.0.0-beta0]: https://github.com/taminomara/python-vhs/compare/v0.0.4...v1.0.0-beta0
